/* Generated at libc build time from kernel syscall list.  */

#ifndef _SYSCALL_H
# error "Never use <bits/syscall.h> directly; include <sys/syscall.h> instead."
#endif

#define SYS_HPUX___cnx_gsched_ctl __NR_HPUX___cnx_gsched_ctl
#define SYS_HPUX___cnx_p2p_ctl __NR_HPUX___cnx_p2p_ctl
#define SYS_HPUX___cnx_pmon_ctl __NR_HPUX___cnx_pmon_ctl
#define SYS_HPUX_accept __NR_HPUX_accept
#define SYS_HPUX_accept_old __NR_HPUX_accept_old
#define SYS_HPUX_access __NR_HPUX_access
#define SYS_HPUX_acct __NR_HPUX_acct
#define SYS_HPUX_acl __NR_HPUX_acl
#define SYS_HPUX_adjtime __NR_HPUX_adjtime
#define SYS_HPUX_aio_cancel __NR_HPUX_aio_cancel
#define SYS_HPUX_aio_cancel64 __NR_HPUX_aio_cancel64
#define SYS_HPUX_aio_error __NR_HPUX_aio_error
#define SYS_HPUX_aio_error64 __NR_HPUX_aio_error64
#define SYS_HPUX_aio_fsync __NR_HPUX_aio_fsync
#define SYS_HPUX_aio_fsync64 __NR_HPUX_aio_fsync64
#define SYS_HPUX_aio_read __NR_HPUX_aio_read
#define SYS_HPUX_aio_read64 __NR_HPUX_aio_read64
#define SYS_HPUX_aio_return __NR_HPUX_aio_return
#define SYS_HPUX_aio_return64 __NR_HPUX_aio_return64
#define SYS_HPUX_aio_suspend __NR_HPUX_aio_suspend
#define SYS_HPUX_aio_suspend64 __NR_HPUX_aio_suspend64
#define SYS_HPUX_aio_write __NR_HPUX_aio_write
#define SYS_HPUX_aio_write64 __NR_HPUX_aio_write64
#define SYS_HPUX_alarm __NR_HPUX_alarm
#define SYS_HPUX_async_daemon __NR_HPUX_async_daemon
#define SYS_HPUX_audctl __NR_HPUX_audctl
#define SYS_HPUX_audswitch __NR_HPUX_audswitch
#define SYS_HPUX_audwrite __NR_HPUX_audwrite
#define SYS_HPUX_bigio __NR_HPUX_bigio
#define SYS_HPUX_bind __NR_HPUX_bind
#define SYS_HPUX_bind_old __NR_HPUX_bind_old
#define SYS_HPUX_break __NR_HPUX_break
#define SYS_HPUX_cachectl __NR_HPUX_cachectl
#define SYS_HPUX_cds __NR_HPUX_cds
#define SYS_HPUX_chdir __NR_HPUX_chdir
#define SYS_HPUX_chmod __NR_HPUX_chmod
#define SYS_HPUX_chown __NR_HPUX_chown
#define SYS_HPUX_chroot __NR_HPUX_chroot
#define SYS_HPUX_clock_getres __NR_HPUX_clock_getres
#define SYS_HPUX_clock_gettime __NR_HPUX_clock_gettime
#define SYS_HPUX_clock_settime __NR_HPUX_clock_settime
#define SYS_HPUX_close __NR_HPUX_close
#define SYS_HPUX_cluster __NR_HPUX_cluster
#define SYS_HPUX_cnodeid __NR_HPUX_cnodeid
#define SYS_HPUX_cnodes __NR_HPUX_cnodes
#define SYS_HPUX_connect __NR_HPUX_connect
#define SYS_HPUX_connect_old __NR_HPUX_connect_old
#define SYS_HPUX_crashconf __NR_HPUX_crashconf
#define SYS_HPUX_creat __NR_HPUX_creat
#define SYS_HPUX_cs __NR_HPUX_cs
#define SYS_HPUX_csp __NR_HPUX_csp
#define SYS_HPUX_dskless_stats __NR_HPUX_dskless_stats
#define SYS_HPUX_dup __NR_HPUX_dup
#define SYS_HPUX_dup2 __NR_HPUX_dup2
#define SYS_HPUX_execv __NR_HPUX_execv
#define SYS_HPUX_execve __NR_HPUX_execve
#define SYS_HPUX_exit __NR_HPUX_exit
#define SYS_HPUX_exportfs __NR_HPUX_exportfs
#define SYS_HPUX_fattach __NR_HPUX_fattach
#define SYS_HPUX_fchdir __NR_HPUX_fchdir
#define SYS_HPUX_fchmod __NR_HPUX_fchmod
#define SYS_HPUX_fchown __NR_HPUX_fchown
#define SYS_HPUX_fcntl __NR_HPUX_fcntl
#define SYS_HPUX_fcntl64 __NR_HPUX_fcntl64
#define SYS_HPUX_fdetach __NR_HPUX_fdetach
#define SYS_HPUX_fgetacl __NR_HPUX_fgetacl
#define SYS_HPUX_flock_old __NR_HPUX_flock_old
#define SYS_HPUX_fork __NR_HPUX_fork
#define SYS_HPUX_fpathconf __NR_HPUX_fpathconf
#define SYS_HPUX_fsctl __NR_HPUX_fsctl
#define SYS_HPUX_fsetacl __NR_HPUX_fsetacl
#define SYS_HPUX_fss __NR_HPUX_fss
#define SYS_HPUX_fstat __NR_HPUX_fstat
#define SYS_HPUX_fstat64 __NR_HPUX_fstat64
#define SYS_HPUX_fstatfs __NR_HPUX_fstatfs
#define SYS_HPUX_fstatvfs __NR_HPUX_fstatvfs
#define SYS_HPUX_fstatvfs64 __NR_HPUX_fstatvfs64
#define SYS_HPUX_fsync __NR_HPUX_fsync
#define SYS_HPUX_ftime __NR_HPUX_ftime
#define SYS_HPUX_ftruncate __NR_HPUX_ftruncate
#define SYS_HPUX_ftruncate64 __NR_HPUX_ftruncate64
#define SYS_HPUX_get_sysinfo __NR_HPUX_get_sysinfo
#define SYS_HPUX_getaccess __NR_HPUX_getaccess
#define SYS_HPUX_getacl __NR_HPUX_getacl
#define SYS_HPUX_getaudid __NR_HPUX_getaudid
#define SYS_HPUX_getaudproc __NR_HPUX_getaudproc
#define SYS_HPUX_getcontext __NR_HPUX_getcontext
#define SYS_HPUX_getcontext_old __NR_HPUX_getcontext_old
#define SYS_HPUX_getdents __NR_HPUX_getdents
#define SYS_HPUX_getdirentries __NR_HPUX_getdirentries
#define SYS_HPUX_getdirentries64 __NR_HPUX_getdirentries64
#define SYS_HPUX_getdomainname __NR_HPUX_getdomainname
#define SYS_HPUX_getdopt __NR_HPUX_getdopt
#define SYS_HPUX_getdtablesize __NR_HPUX_getdtablesize
#define SYS_HPUX_getevent __NR_HPUX_getevent
#define SYS_HPUX_getfh __NR_HPUX_getfh
#define SYS_HPUX_getgid __NR_HPUX_getgid
#define SYS_HPUX_getgroups __NR_HPUX_getgroups
#define SYS_HPUX_gethostid __NR_HPUX_gethostid
#define SYS_HPUX_gethostname42 __NR_HPUX_gethostname42
#define SYS_HPUX_getitimer __NR_HPUX_getitimer
#define SYS_HPUX_getksym __NR_HPUX_getksym
#define SYS_HPUX_getmachineid __NR_HPUX_getmachineid
#define SYS_HPUX_getmount_cnt __NR_HPUX_getmount_cnt
#define SYS_HPUX_getmount_entry __NR_HPUX_getmount_entry
#define SYS_HPUX_getmsg __NR_HPUX_getmsg
#define SYS_HPUX_getnumfds __NR_HPUX_getnumfds
#define SYS_HPUX_getpagesize __NR_HPUX_getpagesize
#define SYS_HPUX_getpeername __NR_HPUX_getpeername
#define SYS_HPUX_getpeername_old __NR_HPUX_getpeername_old
#define SYS_HPUX_getpgrp2 __NR_HPUX_getpgrp2
#define SYS_HPUX_getpid __NR_HPUX_getpid
#define SYS_HPUX_getpmsg __NR_HPUX_getpmsg
#define SYS_HPUX_getpriority __NR_HPUX_getpriority
#define SYS_HPUX_getrlimit __NR_HPUX_getrlimit
#define SYS_HPUX_getrlimit64 __NR_HPUX_getrlimit64
#define SYS_HPUX_getrusage __NR_HPUX_getrusage
#define SYS_HPUX_getsid __NR_HPUX_getsid
#define SYS_HPUX_getsockname __NR_HPUX_getsockname
#define SYS_HPUX_getsockname_old __NR_HPUX_getsockname_old
#define SYS_HPUX_getsockopt __NR_HPUX_getsockopt
#define SYS_HPUX_getsockopt_old __NR_HPUX_getsockopt_old
#define SYS_HPUX_gettimeofday __NR_HPUX_gettimeofday
#define SYS_HPUX_getuid __NR_HPUX_getuid
#define SYS_HPUX_gtty __NR_HPUX_gtty
#define SYS_HPUX_ioctl __NR_HPUX_ioctl
#define SYS_HPUX_ki_call __NR_HPUX_ki_call
#define SYS_HPUX_kill __NR_HPUX_kill
#define SYS_HPUX_killpg_old __NR_HPUX_killpg_old
#define SYS_HPUX_kload __NR_HPUX_kload
#define SYS_HPUX_ksem_close __NR_HPUX_ksem_close
#define SYS_HPUX_ksem_open __NR_HPUX_ksem_open
#define SYS_HPUX_ksem_post __NR_HPUX_ksem_post
#define SYS_HPUX_ksem_read __NR_HPUX_ksem_read
#define SYS_HPUX_ksem_trywait __NR_HPUX_ksem_trywait
#define SYS_HPUX_ksem_unlink __NR_HPUX_ksem_unlink
#define SYS_HPUX_ksem_wait __NR_HPUX_ksem_wait
#define SYS_HPUX_ksleep __NR_HPUX_ksleep
#define SYS_HPUX_kwakeup __NR_HPUX_kwakeup
#define SYS_HPUX_lchmod __NR_HPUX_lchmod
#define SYS_HPUX_lchown __NR_HPUX_lchown
#define SYS_HPUX_lf_free_buf __NR_HPUX_lf_free_buf
#define SYS_HPUX_lf_send_pin_map __NR_HPUX_lf_send_pin_map
#define SYS_HPUX_lf_unused __NR_HPUX_lf_unused
#define SYS_HPUX_lf_unwire_mem __NR_HPUX_lf_unwire_mem
#define SYS_HPUX_lf_wait_nq __NR_HPUX_lf_wait_nq
#define SYS_HPUX_lf_wakeup_conn_q __NR_HPUX_lf_wakeup_conn_q
#define SYS_HPUX_lf_wire_mem __NR_HPUX_lf_wire_mem
#define SYS_HPUX_link __NR_HPUX_link
#define SYS_HPUX_lio_listio __NR_HPUX_lio_listio
#define SYS_HPUX_lio_listio64 __NR_HPUX_lio_listio64
#define SYS_HPUX_listen __NR_HPUX_listen
#define SYS_HPUX_listen_old __NR_HPUX_listen_old
#define SYS_HPUX_lockf __NR_HPUX_lockf
#define SYS_HPUX_lockf64 __NR_HPUX_lockf64
#define SYS_HPUX_lseek __NR_HPUX_lseek
#define SYS_HPUX_lseek64 __NR_HPUX_lseek64
#define SYS_HPUX_lstat __NR_HPUX_lstat
#define SYS_HPUX_lstat64 __NR_HPUX_lstat64
#define SYS_HPUX_lsync __NR_HPUX_lsync
#define SYS_HPUX_lwp_abort_syscall __NR_HPUX_lwp_abort_syscall
#define SYS_HPUX_lwp_cond_broadcast __NR_HPUX_lwp_cond_broadcast
#define SYS_HPUX_lwp_cond_init __NR_HPUX_lwp_cond_init
#define SYS_HPUX_lwp_cond_signal __NR_HPUX_lwp_cond_signal
#define SYS_HPUX_lwp_cond_wait_sys __NR_HPUX_lwp_cond_wait_sys
#define SYS_HPUX_lwp_continue __NR_HPUX_lwp_continue
#define SYS_HPUX_lwp_create __NR_HPUX_lwp_create
#define SYS_HPUX_lwp_detach __NR_HPUX_lwp_detach
#define SYS_HPUX_lwp_detached_exit __NR_HPUX_lwp_detached_exit
#define SYS_HPUX_lwp_exit __NR_HPUX_lwp_exit
#define SYS_HPUX_lwp_getscheduler __NR_HPUX_lwp_getscheduler
#define SYS_HPUX_lwp_getstate __NR_HPUX_lwp_getstate
#define SYS_HPUX_lwp_info __NR_HPUX_lwp_info
#define SYS_HPUX_lwp_kill __NR_HPUX_lwp_kill
#define SYS_HPUX_lwp_mutex_init __NR_HPUX_lwp_mutex_init
#define SYS_HPUX_lwp_mutex_lock_sys __NR_HPUX_lwp_mutex_lock_sys
#define SYS_HPUX_lwp_mutex_unlock __NR_HPUX_lwp_mutex_unlock
#define SYS_HPUX_lwp_resume __NR_HPUX_lwp_resume
#define SYS_HPUX_lwp_rwlock_destroy __NR_HPUX_lwp_rwlock_destroy
#define SYS_HPUX_lwp_rwlock_init __NR_HPUX_lwp_rwlock_init
#define SYS_HPUX_lwp_rwlock_rdlock_sys __NR_HPUX_lwp_rwlock_rdlock_sys
#define SYS_HPUX_lwp_rwlock_tryrdlock __NR_HPUX_lwp_rwlock_tryrdlock
#define SYS_HPUX_lwp_rwlock_trywrlock __NR_HPUX_lwp_rwlock_trywrlock
#define SYS_HPUX_lwp_rwlock_unlock __NR_HPUX_lwp_rwlock_unlock
#define SYS_HPUX_lwp_rwlock_wrlock_sys __NR_HPUX_lwp_rwlock_wrlock_sys
#define SYS_HPUX_lwp_sema_destroy __NR_HPUX_lwp_sema_destroy
#define SYS_HPUX_lwp_sema_init __NR_HPUX_lwp_sema_init
#define SYS_HPUX_lwp_sema_post __NR_HPUX_lwp_sema_post
#define SYS_HPUX_lwp_sema_trywait __NR_HPUX_lwp_sema_trywait
#define SYS_HPUX_lwp_sema_wait __NR_HPUX_lwp_sema_wait
#define SYS_HPUX_lwp_setscheduler __NR_HPUX_lwp_setscheduler
#define SYS_HPUX_lwp_setstate __NR_HPUX_lwp_setstate
#define SYS_HPUX_lwp_suspend __NR_HPUX_lwp_suspend
#define SYS_HPUX_lwp_terminate __NR_HPUX_lwp_terminate
#define SYS_HPUX_lwp_wait __NR_HPUX_lwp_wait
#define SYS_HPUX_m68020_advise __NR_HPUX_m68020_advise
#define SYS_HPUX_madvise __NR_HPUX_madvise
#define SYS_HPUX_mincore __NR_HPUX_mincore
#define SYS_HPUX_mkdir __NR_HPUX_mkdir
#define SYS_HPUX_mknod __NR_HPUX_mknod
#define SYS_HPUX_mkrnod __NR_HPUX_mkrnod
#define SYS_HPUX_mlock __NR_HPUX_mlock
#define SYS_HPUX_mlockall __NR_HPUX_mlockall
#define SYS_HPUX_mmap __NR_HPUX_mmap
#define SYS_HPUX_mmap64 __NR_HPUX_mmap64
#define SYS_HPUX_modadm __NR_HPUX_modadm
#define SYS_HPUX_modload __NR_HPUX_modload
#define SYS_HPUX_modpath __NR_HPUX_modpath
#define SYS_HPUX_modstat __NR_HPUX_modstat
#define SYS_HPUX_moduload __NR_HPUX_moduload
#define SYS_HPUX_mount __NR_HPUX_mount
#define SYS_HPUX_mpctl __NR_HPUX_mpctl
#define SYS_HPUX_mprotect __NR_HPUX_mprotect
#define SYS_HPUX_mq_close __NR_HPUX_mq_close
#define SYS_HPUX_mq_getattr __NR_HPUX_mq_getattr
#define SYS_HPUX_mq_notify __NR_HPUX_mq_notify
#define SYS_HPUX_mq_open __NR_HPUX_mq_open
#define SYS_HPUX_mq_receive __NR_HPUX_mq_receive
#define SYS_HPUX_mq_send __NR_HPUX_mq_send
#define SYS_HPUX_mq_setattr __NR_HPUX_mq_setattr
#define SYS_HPUX_mq_unlink __NR_HPUX_mq_unlink
#define SYS_HPUX_mremap __NR_HPUX_mremap
#define SYS_HPUX_msem_init __NR_HPUX_msem_init
#define SYS_HPUX_msem_remove __NR_HPUX_msem_remove
#define SYS_HPUX_msgctl __NR_HPUX_msgctl
#define SYS_HPUX_msgget __NR_HPUX_msgget
#define SYS_HPUX_msgrecv __NR_HPUX_msgrecv
#define SYS_HPUX_msgsnd __NR_HPUX_msgsnd
#define SYS_HPUX_msh_register __NR_HPUX_msh_register
#define SYS_HPUX_msleep __NR_HPUX_msleep
#define SYS_HPUX_msync __NR_HPUX_msync
#define SYS_HPUX_munlock __NR_HPUX_munlock
#define SYS_HPUX_munlockall __NR_HPUX_munlockall
#define SYS_HPUX_munmap __NR_HPUX_munmap
#define SYS_HPUX_mwakeup __NR_HPUX_mwakeup
#define SYS_HPUX_nanosleep __NR_HPUX_nanosleep
#define SYS_HPUX_nfs_fcntl __NR_HPUX_nfs_fcntl
#define SYS_HPUX_nfs_kstat __NR_HPUX_nfs_kstat
#define SYS_HPUX_nfssvc __NR_HPUX_nfssvc
#define SYS_HPUX_nice __NR_HPUX_nice
#define SYS_HPUX_ofgetacl __NR_HPUX_ofgetacl
#define SYS_HPUX_ofsetacl __NR_HPUX_ofsetacl
#define SYS_HPUX_ogetaccess __NR_HPUX_ogetaccess
#define SYS_HPUX_ogetacl __NR_HPUX_ogetacl
#define SYS_HPUX_oldfstat __NR_HPUX_oldfstat
#define SYS_HPUX_oldlock __NR_HPUX_oldlock
#define SYS_HPUX_omsgctl __NR_HPUX_omsgctl
#define SYS_HPUX_open __NR_HPUX_open
#define SYS_HPUX_osemctl __NR_HPUX_osemctl
#define SYS_HPUX_osetacl __NR_HPUX_osetacl
#define SYS_HPUX_osetcontext __NR_HPUX_osetcontext
#define SYS_HPUX_oshmctl __NR_HPUX_oshmctl
#define SYS_HPUX_pathconf __NR_HPUX_pathconf
#define SYS_HPUX_pause __NR_HPUX_pause
#define SYS_HPUX_pipe __NR_HPUX_pipe
#define SYS_HPUX_pipenode __NR_HPUX_pipenode
#define SYS_HPUX_plock __NR_HPUX_plock
#define SYS_HPUX_poll __NR_HPUX_poll
#define SYS_HPUX_pread __NR_HPUX_pread
#define SYS_HPUX_pread64 __NR_HPUX_pread64
#define SYS_HPUX_preadv __NR_HPUX_preadv
#define SYS_HPUX_preadv64 __NR_HPUX_preadv64
#define SYS_HPUX_privgrp __NR_HPUX_privgrp
#define SYS_HPUX_proc_close __NR_HPUX_proc_close
#define SYS_HPUX_proc_open __NR_HPUX_proc_open
#define SYS_HPUX_proc_recv __NR_HPUX_proc_recv
#define SYS_HPUX_proc_send __NR_HPUX_proc_send
#define SYS_HPUX_proc_sendrecv __NR_HPUX_proc_sendrecv
#define SYS_HPUX_proc_syscall __NR_HPUX_proc_syscall
#define SYS_HPUX_profil __NR_HPUX_profil
#define SYS_HPUX_pstat __NR_HPUX_pstat
#define SYS_HPUX_pstat_getlwp __NR_HPUX_pstat_getlwp
#define SYS_HPUX_ptrace __NR_HPUX_ptrace
#define SYS_HPUX_ptrace64 __NR_HPUX_ptrace64
#define SYS_HPUX_putmsg __NR_HPUX_putmsg
#define SYS_HPUX_putpmsg __NR_HPUX_putpmsg
#define SYS_HPUX_pwrite __NR_HPUX_pwrite
#define SYS_HPUX_pwrite64 __NR_HPUX_pwrite64
#define SYS_HPUX_pwritev __NR_HPUX_pwritev
#define SYS_HPUX_pwritev64 __NR_HPUX_pwritev64
#define SYS_HPUX_quotactl __NR_HPUX_quotactl
#define SYS_HPUX_read __NR_HPUX_read
#define SYS_HPUX_readlink __NR_HPUX_readlink
#define SYS_HPUX_readv __NR_HPUX_readv
#define SYS_HPUX_reboot __NR_HPUX_reboot
#define SYS_HPUX_recv __NR_HPUX_recv
#define SYS_HPUX_recv2 __NR_HPUX_recv2
#define SYS_HPUX_recv_old __NR_HPUX_recv_old
#define SYS_HPUX_recvfrom __NR_HPUX_recvfrom
#define SYS_HPUX_recvfrom2 __NR_HPUX_recvfrom2
#define SYS_HPUX_recvfrom_old __NR_HPUX_recvfrom_old
#define SYS_HPUX_recvmsg __NR_HPUX_recvmsg
#define SYS_HPUX_recvmsg2 __NR_HPUX_recvmsg2
#define SYS_HPUX_recvmsg_old __NR_HPUX_recvmsg_old
#define SYS_HPUX_rename __NR_HPUX_rename
#define SYS_HPUX_reserved1 __NR_HPUX_reserved1
#define SYS_HPUX_reserved2 __NR_HPUX_reserved2
#define SYS_HPUX_reserved3 __NR_HPUX_reserved3
#define SYS_HPUX_reserved4 __NR_HPUX_reserved4
#define SYS_HPUX_reserved5 __NR_HPUX_reserved5
#define SYS_HPUX_reserved6 __NR_HPUX_reserved6
#define SYS_HPUX_resuba_old __NR_HPUX_resuba_old
#define SYS_HPUX_rmdir __NR_HPUX_rmdir
#define SYS_HPUX_rmt_process __NR_HPUX_rmt_process
#define SYS_HPUX_rtprio __NR_HPUX_rtprio
#define SYS_HPUX_sbrk __NR_HPUX_sbrk
#define SYS_HPUX_sched_get_priority_max __NR_HPUX_sched_get_priority_max
#define SYS_HPUX_sched_get_priority_min __NR_HPUX_sched_get_priority_min
#define SYS_HPUX_sched_getparam __NR_HPUX_sched_getparam
#define SYS_HPUX_sched_getscheduler __NR_HPUX_sched_getscheduler
#define SYS_HPUX_sched_rr_get_interval __NR_HPUX_sched_rr_get_interval
#define SYS_HPUX_sched_setparam __NR_HPUX_sched_setparam
#define SYS_HPUX_sched_setscheduler __NR_HPUX_sched_setscheduler
#define SYS_HPUX_sched_yield __NR_HPUX_sched_yield
#define SYS_HPUX_select __NR_HPUX_select
#define SYS_HPUX_semctl __NR_HPUX_semctl
#define SYS_HPUX_semget __NR_HPUX_semget
#define SYS_HPUX_semop __NR_HPUX_semop
#define SYS_HPUX_send __NR_HPUX_send
#define SYS_HPUX_send2 __NR_HPUX_send2
#define SYS_HPUX_send_old __NR_HPUX_send_old
#define SYS_HPUX_sendfile __NR_HPUX_sendfile
#define SYS_HPUX_sendfile64 __NR_HPUX_sendfile64
#define SYS_HPUX_sendmsg __NR_HPUX_sendmsg
#define SYS_HPUX_sendmsg2 __NR_HPUX_sendmsg2
#define SYS_HPUX_sendmsg_old __NR_HPUX_sendmsg_old
#define SYS_HPUX_sendpath __NR_HPUX_sendpath
#define SYS_HPUX_sendpath64 __NR_HPUX_sendpath64
#define SYS_HPUX_sendto __NR_HPUX_sendto
#define SYS_HPUX_sendto2 __NR_HPUX_sendto2
#define SYS_HPUX_sendto_old __NR_HPUX_sendto_old
#define SYS_HPUX_serialize __NR_HPUX_serialize
#define SYS_HPUX_set_no_trunc __NR_HPUX_set_no_trunc
#define SYS_HPUX_set_userthreadid __NR_HPUX_set_userthreadid
#define SYS_HPUX_setacl __NR_HPUX_setacl
#define SYS_HPUX_setaudid __NR_HPUX_setaudid
#define SYS_HPUX_setaudproc __NR_HPUX_setaudproc
#define SYS_HPUX_setcontext __NR_HPUX_setcontext
#define SYS_HPUX_setcore __NR_HPUX_setcore
#define SYS_HPUX_setdomainname __NR_HPUX_setdomainname
#define SYS_HPUX_setdopt __NR_HPUX_setdopt
#define SYS_HPUX_setevent __NR_HPUX_setevent
#define SYS_HPUX_setgid __NR_HPUX_setgid
#define SYS_HPUX_setgroups __NR_HPUX_setgroups
#define SYS_HPUX_sethostid __NR_HPUX_sethostid
#define SYS_HPUX_sethostname42 __NR_HPUX_sethostname42
#define SYS_HPUX_setitimer __NR_HPUX_setitimer
#define SYS_HPUX_setpgrp __NR_HPUX_setpgrp
#define SYS_HPUX_setpgrp2 __NR_HPUX_setpgrp2
#define SYS_HPUX_setpgrp3 __NR_HPUX_setpgrp3
#define SYS_HPUX_setpriority __NR_HPUX_setpriority
#define SYS_HPUX_setregid __NR_HPUX_setregid
#define SYS_HPUX_setresgid __NR_HPUX_setresgid
#define SYS_HPUX_setresuid __NR_HPUX_setresuid
#define SYS_HPUX_setrlimit __NR_HPUX_setrlimit
#define SYS_HPUX_setrlimit64 __NR_HPUX_setrlimit64
#define SYS_HPUX_setsockopt __NR_HPUX_setsockopt
#define SYS_HPUX_setsockopt_old __NR_HPUX_setsockopt_old
#define SYS_HPUX_settimeofday __NR_HPUX_settimeofday
#define SYS_HPUX_setuid __NR_HPUX_setuid
#define SYS_HPUX_shm_open __NR_HPUX_shm_open
#define SYS_HPUX_shm_unlink __NR_HPUX_shm_unlink
#define SYS_HPUX_shmat __NR_HPUX_shmat
#define SYS_HPUX_shmctl __NR_HPUX_shmctl
#define SYS_HPUX_shmdt __NR_HPUX_shmdt
#define SYS_HPUX_shmget __NR_HPUX_shmget
#define SYS_HPUX_shutdown __NR_HPUX_shutdown
#define SYS_HPUX_shutdown_old __NR_HPUX_shutdown_old
#define SYS_HPUX_sigaction __NR_HPUX_sigaction
#define SYS_HPUX_sigaltstack __NR_HPUX_sigaltstack
#define SYS_HPUX_sigblock __NR_HPUX_sigblock
#define SYS_HPUX_sigcleanup_old __NR_HPUX_sigcleanup_old
#define SYS_HPUX_sigenable __NR_HPUX_sigenable
#define SYS_HPUX_siggetmask __NR_HPUX_siggetmask
#define SYS_HPUX_siginhibit __NR_HPUX_siginhibit
#define SYS_HPUX_sigpause __NR_HPUX_sigpause
#define SYS_HPUX_sigpending __NR_HPUX_sigpending
#define SYS_HPUX_sigprocmask __NR_HPUX_sigprocmask
#define SYS_HPUX_sigqueue __NR_HPUX_sigqueue
#define SYS_HPUX_sigsetreturn __NR_HPUX_sigsetreturn
#define SYS_HPUX_sigsetstatemask __NR_HPUX_sigsetstatemask
#define SYS_HPUX_sigstack __NR_HPUX_sigstack
#define SYS_HPUX_sigsuspend __NR_HPUX_sigsuspend
#define SYS_HPUX_sigsys __NR_HPUX_sigsys
#define SYS_HPUX_sigtimedwait __NR_HPUX_sigtimedwait
#define SYS_HPUX_sigvector __NR_HPUX_sigvector
#define SYS_HPUX_sigwait __NR_HPUX_sigwait
#define SYS_HPUX_sigwaitinfo __NR_HPUX_sigwaitinfo
#define SYS_HPUX_socket __NR_HPUX_socket
#define SYS_HPUX_socket2 __NR_HPUX_socket2
#define SYS_HPUX_socket_old __NR_HPUX_socket_old
#define SYS_HPUX_socketaddr_old __NR_HPUX_socketaddr_old
#define SYS_HPUX_socketpair __NR_HPUX_socketpair
#define SYS_HPUX_socketpair2 __NR_HPUX_socketpair2
#define SYS_HPUX_socketpair_old __NR_HPUX_socketpair_old
#define SYS_HPUX_spuctl __NR_HPUX_spuctl
#define SYS_HPUX_sstk __NR_HPUX_sstk
#define SYS_HPUX_stat __NR_HPUX_stat
#define SYS_HPUX_stat64 __NR_HPUX_stat64
#define SYS_HPUX_statfs __NR_HPUX_statfs
#define SYS_HPUX_statvfs __NR_HPUX_statvfs
#define SYS_HPUX_statvfs64 __NR_HPUX_statvfs64
#define SYS_HPUX_stime __NR_HPUX_stime
#define SYS_HPUX_stty __NR_HPUX_stty
#define SYS_HPUX_swapclients __NR_HPUX_swapclients
#define SYS_HPUX_swapfs __NR_HPUX_swapfs
#define SYS_HPUX_swapoff __NR_HPUX_swapoff
#define SYS_HPUX_swapon __NR_HPUX_swapon
#define SYS_HPUX_symlink __NR_HPUX_symlink
#define SYS_HPUX_sync __NR_HPUX_sync
#define SYS_HPUX_syscalls __NR_HPUX_syscalls
#define SYS_HPUX_sysconf __NR_HPUX_sysconf
#define SYS_HPUX_sysfs __NR_HPUX_sysfs
#define SYS_HPUX_sysinfo __NR_HPUX_sysinfo
#define SYS_HPUX_test __NR_HPUX_test
#define SYS_HPUX_time __NR_HPUX_time
#define SYS_HPUX_timer_create __NR_HPUX_timer_create
#define SYS_HPUX_timer_delete __NR_HPUX_timer_delete
#define SYS_HPUX_timer_getoverrun __NR_HPUX_timer_getoverrun
#define SYS_HPUX_timer_gettime __NR_HPUX_timer_gettime
#define SYS_HPUX_timer_settime __NR_HPUX_timer_settime
#define SYS_HPUX_times __NR_HPUX_times
#define SYS_HPUX_toolbox __NR_HPUX_toolbox
#define SYS_HPUX_truncate __NR_HPUX_truncate
#define SYS_HPUX_truncate64 __NR_HPUX_truncate64
#define SYS_HPUX_tsync __NR_HPUX_tsync
#define SYS_HPUX_ttrace __NR_HPUX_ttrace
#define SYS_HPUX_ttrace_wait __NR_HPUX_ttrace_wait
#define SYS_HPUX_ulimit __NR_HPUX_ulimit
#define SYS_HPUX_ulimit64 __NR_HPUX_ulimit64
#define SYS_HPUX_umask __NR_HPUX_umask
#define SYS_HPUX_umount __NR_HPUX_umount
#define SYS_HPUX_unlink __NR_HPUX_unlink
#define SYS_HPUX_unsp_open __NR_HPUX_unsp_open
#define SYS_HPUX_utime __NR_HPUX_utime
#define SYS_HPUX_utimes_old __NR_HPUX_utimes_old
#define SYS_HPUX_utssys __NR_HPUX_utssys
#define SYS_HPUX_vadvise __NR_HPUX_vadvise
#define SYS_HPUX_vfork __NR_HPUX_vfork
#define SYS_HPUX_vfsmount __NR_HPUX_vfsmount
#define SYS_HPUX_vhangup __NR_HPUX_vhangup
#define SYS_HPUX_vread __NR_HPUX_vread
#define SYS_HPUX_vtimes_old __NR_HPUX_vtimes_old
#define SYS_HPUX_vtrace_old __NR_HPUX_vtrace_old
#define SYS_HPUX_vwrite __NR_HPUX_vwrite
#define SYS_HPUX_wait __NR_HPUX_wait
#define SYS_HPUX_wait3 __NR_HPUX_wait3
#define SYS_HPUX_waitid __NR_HPUX_waitid
#define SYS_HPUX_waitpid __NR_HPUX_waitpid
#define SYS_HPUX_write __NR_HPUX_write
#define SYS_HPUX_writev __NR_HPUX_writev
#define SYS_HPUX_zerokernelsum __NR_HPUX_zerokernelsum
#define SYS_Linux __NR_Linux
#define SYS_Linux_syscalls __NR_Linux_syscalls
#define SYS__llseek __NR__llseek
#define SYS__newselect __NR__newselect
#define SYS__sysctl __NR__sysctl
#define SYS_accept __NR_accept
#define SYS_access __NR_access
#define SYS_acct __NR_acct
#define SYS_acl_get __NR_acl_get
#define SYS_acl_set __NR_acl_set
#define SYS_adjtimex __NR_adjtimex
#define SYS_afs_syscall __NR_afs_syscall
#define SYS_alarm __NR_alarm
#define SYS_alloc_hugepages __NR_alloc_hugepages
#define SYS_attrctl __NR_attrctl
#define SYS_bdflush __NR_bdflush
#define SYS_bind __NR_bind
#define SYS_brk __NR_brk
#define SYS_capget __NR_capget
#define SYS_capset __NR_capset
#define SYS_chdir __NR_chdir
#define SYS_chmod __NR_chmod
#define SYS_chown __NR_chown
#define SYS_chroot __NR_chroot
#define SYS_clock_getres __NR_clock_getres
#define SYS_clock_gettime __NR_clock_gettime
#define SYS_clock_nanosleep __NR_clock_nanosleep
#define SYS_clock_settime __NR_clock_settime
#define SYS_clone __NR_clone
#define SYS_close __NR_close
#define SYS_connect __NR_connect
#define SYS_creat __NR_creat
#define SYS_create_module __NR_create_module
#define SYS_delete_module __NR_delete_module
#define SYS_dup __NR_dup
#define SYS_dup2 __NR_dup2
#define SYS_epoll_create __NR_epoll_create
#define SYS_epoll_ctl __NR_epoll_ctl
#define SYS_epoll_wait __NR_epoll_wait
#define SYS_execve __NR_execve
#define SYS_exit __NR_exit
#define SYS_exit_group __NR_exit_group
#define SYS_fadvise64_64 __NR_fadvise64_64
#define SYS_fchdir __NR_fchdir
#define SYS_fchmod __NR_fchmod
#define SYS_fchown __NR_fchown
#define SYS_fcntl __NR_fcntl
#define SYS_fcntl64 __NR_fcntl64
#define SYS_fdatasync __NR_fdatasync
#define SYS_fgetxattr __NR_fgetxattr
#define SYS_flistxattr __NR_flistxattr
#define SYS_flock __NR_flock
#define SYS_fork __NR_fork
#define SYS_free_hugepages __NR_free_hugepages
#define SYS_fremovexattr __NR_fremovexattr
#define SYS_fsetxattr __NR_fsetxattr
#define SYS_fstat __NR_fstat
#define SYS_fstat64 __NR_fstat64
#define SYS_fstatfs __NR_fstatfs
#define SYS_fsync __NR_fsync
#define SYS_ftruncate __NR_ftruncate
#define SYS_ftruncate64 __NR_ftruncate64
#define SYS_futex __NR_futex
#define SYS_get_kernel_syms __NR_get_kernel_syms
#define SYS_get_mempolicy __NR_get_mempolicy
#define SYS_get_thread_area __NR_get_thread_area
#define SYS_getcwd __NR_getcwd
#define SYS_getdents __NR_getdents
#define SYS_getdents64 __NR_getdents64
#define SYS_getegid __NR_getegid
#define SYS_geteuid __NR_geteuid
#define SYS_getgid __NR_getgid
#define SYS_getgroups __NR_getgroups
#define SYS_getitimer __NR_getitimer
#define SYS_getpeername __NR_getpeername
#define SYS_getpgid __NR_getpgid
#define SYS_getpgrp __NR_getpgrp
#define SYS_getpid __NR_getpid
#define SYS_getpmsg __NR_getpmsg
#define SYS_getppid __NR_getppid
#define SYS_getpriority __NR_getpriority
#define SYS_getresgid __NR_getresgid
#define SYS_getresuid __NR_getresuid
#define SYS_getrlimit __NR_getrlimit
#define SYS_getrusage __NR_getrusage
#define SYS_getsid __NR_getsid
#define SYS_getsockname __NR_getsockname
#define SYS_getsockopt __NR_getsockopt
#define SYS_gettid __NR_gettid
#define SYS_gettimeofday __NR_gettimeofday
#define SYS_getuid __NR_getuid
#define SYS_getxattr __NR_getxattr
#define SYS_init_module __NR_init_module
#define SYS_io_cancel __NR_io_cancel
#define SYS_io_destroy __NR_io_destroy
#define SYS_io_getevents __NR_io_getevents
#define SYS_io_setup __NR_io_setup
#define SYS_io_submit __NR_io_submit
#define SYS_ioctl __NR_ioctl
#define SYS_kill __NR_kill
#define SYS_lchown __NR_lchown
#define SYS_lgetxattr __NR_lgetxattr
#define SYS_link __NR_link
#define SYS_listen __NR_listen
#define SYS_listxattr __NR_listxattr
#define SYS_llistxattr __NR_llistxattr
#define SYS_lookup_dcookie __NR_lookup_dcookie
#define SYS_lremovexattr __NR_lremovexattr
#define SYS_lseek __NR_lseek
#define SYS_lsetxattr __NR_lsetxattr
#define SYS_lstat __NR_lstat
#define SYS_lstat64 __NR_lstat64
#define SYS_madvise __NR_madvise
#define SYS_mbind __NR_mbind
#define SYS_mincore __NR_mincore
#define SYS_mkdir __NR_mkdir
#define SYS_mknod __NR_mknod
#define SYS_mlock __NR_mlock
#define SYS_mlockall __NR_mlockall
#define SYS_mmap __NR_mmap
#define SYS_mmap2 __NR_mmap2
#define SYS_mount __NR_mount
#define SYS_mprotect __NR_mprotect
#define SYS_mq_getsetattr __NR_mq_getsetattr
#define SYS_mq_notify __NR_mq_notify
#define SYS_mq_open __NR_mq_open
#define SYS_mq_timedreceive __NR_mq_timedreceive
#define SYS_mq_timedsend __NR_mq_timedsend
#define SYS_mq_unlink __NR_mq_unlink
#define SYS_mremap __NR_mremap
#define SYS_msgctl __NR_msgctl
#define SYS_msgget __NR_msgget
#define SYS_msgrcv __NR_msgrcv
#define SYS_msgsnd __NR_msgsnd
#define SYS_msync __NR_msync
#define SYS_munlock __NR_munlock
#define SYS_munlockall __NR_munlockall
#define SYS_munmap __NR_munmap
#define SYS_nanosleep __NR_nanosleep
#define SYS_nfsservctl __NR_nfsservctl
#define SYS_nice __NR_nice
#define SYS_open __NR_open
#define SYS_pause __NR_pause
#define SYS_personality __NR_personality
#define SYS_pipe __NR_pipe
#define SYS_pivot_root __NR_pivot_root
#define SYS_poll __NR_poll
#define SYS_prctl __NR_prctl
#define SYS_pread64 __NR_pread64
#define SYS_ptrace __NR_ptrace
#define SYS_putpmsg __NR_putpmsg
#define SYS_pwrite64 __NR_pwrite64
#define SYS_query_module __NR_query_module
#define SYS_quotactl __NR_quotactl
#define SYS_read __NR_read
#define SYS_readahead __NR_readahead
#define SYS_readlink __NR_readlink
#define SYS_readv __NR_readv
#define SYS_reboot __NR_reboot
#define SYS_recv __NR_recv
#define SYS_recvfrom __NR_recvfrom
#define SYS_recvmsg __NR_recvmsg
#define SYS_remap_file_pages __NR_remap_file_pages
#define SYS_removexattr __NR_removexattr
#define SYS_rename __NR_rename
#define SYS_restart_syscall __NR_restart_syscall
#define SYS_rmdir __NR_rmdir
#define SYS_rt_sigaction __NR_rt_sigaction
#define SYS_rt_sigpending __NR_rt_sigpending
#define SYS_rt_sigprocmask __NR_rt_sigprocmask
#define SYS_rt_sigqueueinfo __NR_rt_sigqueueinfo
#define SYS_rt_sigreturn __NR_rt_sigreturn
#define SYS_rt_sigsuspend __NR_rt_sigsuspend
#define SYS_rt_sigtimedwait __NR_rt_sigtimedwait
#define SYS_sched_get_priority_max __NR_sched_get_priority_max
#define SYS_sched_get_priority_min __NR_sched_get_priority_min
#define SYS_sched_getaffinity __NR_sched_getaffinity
#define SYS_sched_getparam __NR_sched_getparam
#define SYS_sched_getscheduler __NR_sched_getscheduler
#define SYS_sched_rr_get_interval __NR_sched_rr_get_interval
#define SYS_sched_setaffinity __NR_sched_setaffinity
#define SYS_sched_setparam __NR_sched_setparam
#define SYS_sched_setscheduler __NR_sched_setscheduler
#define SYS_sched_yield __NR_sched_yield
#define SYS_semctl __NR_semctl
#define SYS_semget __NR_semget
#define SYS_semop __NR_semop
#define SYS_semtimedop __NR_semtimedop
#define SYS_send __NR_send
#define SYS_sendfile __NR_sendfile
#define SYS_sendfile64 __NR_sendfile64
#define SYS_sendmsg __NR_sendmsg
#define SYS_sendto __NR_sendto
#define SYS_set_mempolicy __NR_set_mempolicy
#define SYS_set_thread_area __NR_set_thread_area
#define SYS_set_tid_address __NR_set_tid_address
#define SYS_setdomainname __NR_setdomainname
#define SYS_setfsgid __NR_setfsgid
#define SYS_setfsuid __NR_setfsuid
#define SYS_setgid __NR_setgid
#define SYS_setgroups __NR_setgroups
#define SYS_sethostname __NR_sethostname
#define SYS_setitimer __NR_setitimer
#define SYS_setpgid __NR_setpgid
#define SYS_setpriority __NR_setpriority
#define SYS_setregid __NR_setregid
#define SYS_setresgid __NR_setresgid
#define SYS_setresuid __NR_setresuid
#define SYS_setreuid __NR_setreuid
#define SYS_setrlimit __NR_setrlimit
#define SYS_setsid __NR_setsid
#define SYS_setsockopt __NR_setsockopt
#define SYS_settimeofday __NR_settimeofday
#define SYS_setuid __NR_setuid
#define SYS_setxattr __NR_setxattr
#define SYS_sgetmask __NR_sgetmask
#define SYS_shmat __NR_shmat
#define SYS_shmctl __NR_shmctl
#define SYS_shmdt __NR_shmdt
#define SYS_shmget __NR_shmget
#define SYS_shutdown __NR_shutdown
#define SYS_sigaltstack __NR_sigaltstack
#define SYS_signal __NR_signal
#define SYS_sigpending __NR_sigpending
#define SYS_sigprocmask __NR_sigprocmask
#define SYS_socket __NR_socket
#define SYS_socketpair __NR_socketpair
#define SYS_ssetmask __NR_ssetmask
#define SYS_stat __NR_stat
#define SYS_stat64 __NR_stat64
#define SYS_statfs __NR_statfs
#define SYS_stime __NR_stime
#define SYS_swapoff __NR_swapoff
#define SYS_swapon __NR_swapon
#define SYS_symlink __NR_symlink
#define SYS_sync __NR_sync
#define SYS_sysfs __NR_sysfs
#define SYS_sysinfo __NR_sysinfo
#define SYS_syslog __NR_syslog
#define SYS_tgkill __NR_tgkill
#define SYS_time __NR_time
#define SYS_timer_create __NR_timer_create
#define SYS_timer_delete __NR_timer_delete
#define SYS_timer_getoverrun __NR_timer_getoverrun
#define SYS_timer_gettime __NR_timer_gettime
#define SYS_timer_settime __NR_timer_settime
#define SYS_times __NR_times
#define SYS_tkill __NR_tkill
#define SYS_truncate __NR_truncate
#define SYS_truncate64 __NR_truncate64
#define SYS_umask __NR_umask
#define SYS_umount2 __NR_umount2
#define SYS_uname __NR_uname
#define SYS_unlink __NR_unlink
#define SYS_uselib __NR_uselib
#define SYS_ustat __NR_ustat
#define SYS_utime __NR_utime
#define SYS_vfork __NR_vfork
#define SYS_vhangup __NR_vhangup
#define SYS_wait4 __NR_wait4
#define SYS_waitid __NR_waitid
#define SYS_waitpid __NR_waitpid
#define SYS_write __NR_write
#define SYS_writev __NR_writev
